@@ -216,7 +216,7 @@ sanity_check_window_position (int *left, int *top)
 }
 
 static void
-sanity_check_window_dimensions (int *width, int *height)
+sanity_check_window_dimensions (guint *width, guint *height)
 {
 	g_assert (width != NULL);
 	g_assert (height != NULL);
@@ -259,8 +259,6 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 	int screen_width, screen_height;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
-	g_return_if_fail (!(geometry_flags & EEL_GDK_WIDTH_VALUE) || width > 0);
-	g_return_if_fail (!(geometry_flags & EEL_GDK_HEIGHT_VALUE) || height > 0);
 
 	/* Setting the default size doesn't work when the window is already showing.
 	 * Someday we could make this move an already-showing window, but we don't
@@ -295,7 +293,7 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 
 	if ((geometry_flags & EEL_GDK_WIDTH_VALUE) && (geometry_flags & EEL_GDK_HEIGHT_VALUE)) {
 		sanity_check_window_dimensions (&width, &height);
-		gtk_window_set_default_size (GTK_WINDOW (window), width, height);
+		gtk_window_set_default_size (GTK_WINDOW (window), (int)width, (int)height);
 	}
 }
 
@@ -356,19 +354,6 @@ eel_gtk_window_set_initial_geometry_from_string (GtkWindow *window,
 	eel_gtk_window_set_initial_geometry (window, geometry_flags, left, top, width, height);
 }
 
-/**
- * eel_truncate_text_for_menu_item:
- * 
- * Given an arbitrary string, returns a newly-allocated string
- * suitable for use as a menu item label. Truncates long strings 
- * in the middle.
- */
-char *
-eel_truncate_text_for_menu_item (const char *text)
-{
-	return eel_str_middle_truncate (text, MAXIMUM_MENU_TITLE_LENGTH);
-}
-
 /**
  * eel_pop_up_context_menu:
  * 
